@@ -19,9 +19,7 @@ DEFAULT_MARKDOWN_EXTRAS = [
     "toc",
 ]
 
-DEFAULT_COLTRANE_SETTINGS = {
-    "MARKDOWN_EXTRAS": DEFAULT_MARKDOWN_EXTRAS,
-}
+DEFAULT_COLTRANE_SETTINGS = {"MARKDOWN_EXTRAS": DEFAULT_MARKDOWN_EXTRAS}
 
 
 def get_coltrane_settings() -> Dict:
