@@ -1,7 +1,8 @@
 import logging
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from typing import Dict, Optional, Tuple, Union
 
+from django.conf import settings
 from django.http import HttpRequest
 from django.template import engines
 from django.utils.html import mark_safe  # type: ignore
@@ -29,18 +30,33 @@ class StaticRequest:
     """
 
     path: str
+    META: Dict = field(default_factory=dict)
+    GET: Dict = field(default_factory=dict)
+
+    @property
+    def site(self):
+        _site = settings.COLTRANE.get("SITE")
+        assert _site, "COLTRANE_SITE is required in .env"
+
+        return _site
+
+    @property
+    def scheme(self) -> str:
+        return self.site.split("://")[0]
+
+    def get_host(self) -> str:
+        return self.site.split("://")[1]
 
 
-def _get_markdown_content_as_html(slug: str) -> Dict[str, Optional[Dict]]:
+def render_markdown_path(path) -> Dict[str, Optional[Dict]]:
     """
-    Converts markdown file based on the slug into HTML.
+    Renders the markdown file located at path.
     """
 
-    file_path = get_content_directory() / f"{slug}.md"
     markdown_extras = get_markdown_extras()
 
     content = markdown_path(
-        file_path,
+        path,
         extras=markdown_extras,
     )
 
@@ -48,10 +64,31 @@ def _get_markdown_content_as_html(slug: str) -> Dict[str, Optional[Dict]]:
 
     metadata = content.metadata
 
+    if metadata is None:
+        metadata = {}
+
+    if "date" in metadata:
+        metadata["date"] = dateparser.parse(metadata["date"])
+
+    if "draft" in metadata:
+        metadata["draft"] = metadata["draft"] == "true"
+
+    metadata["now"] = now()
+
     return (str(content), metadata)
 
 
-def _render_html_with_django(
+def _get_markdown_content_as_html(slug: str) -> Dict[str, Optional[Dict]]:
+    """
+    Converts markdown file based on the slug into HTML.
+    """
+
+    path = get_content_directory() / f"{slug}.md"
+
+    return render_markdown_path(path)
+
+
+def render_html_with_django(
     html: str, context: Dict, request: HttpRequest = None
 ) -> str:
     """
@@ -76,14 +113,6 @@ def get_html_and_markdown(slug: str) -> Tuple[str, Dict]:
 
     metadata["slug"] = slug
 
-    if "date" in metadata:
-        metadata["date"] = dateparser.parse(metadata["date"])
-
-    if "draft" in metadata:
-        metadata["draft"] = metadata["draft"] == "true"
-
-    metadata["now"] = now
-
     return (html, metadata)
 
 
@@ -112,7 +141,7 @@ def render_markdown(
     context["data"] = data
 
     # Add rendered content to the context
-    content = _render_html_with_django(html, context, request)
+    content = render_html_with_django(html, context, request)
     context["content"] = mark_safe(content)
     template = context["template"]
 
